@@ -1,5 +1,5 @@
 
-# $Id: ConditionalTree.R 4596 2010-09-13 12:07:18Z hothorn $
+# $Id: ConditionalTree.R 467 2012-02-16 14:18:23Z thothorn $
 
 ### the fitting procedure
 ctreefit <- function(object, controls, weights = NULL, fitmem = NULL, ...) {
@@ -90,10 +90,18 @@ ctreefit <- function(object, controls, weights = NULL, fitmem = NULL, ...) {
     }
 
     ### predict in the response space, always!
-    RET@predict_response <- function(newdata = NULL, mincriterion = 0, ...) { 
+    RET@predict_response <- function(newdata = NULL, mincriterion = 0, 
+        type = c("response", "node", "prob"), ...) { 
+
+        type <- match.arg(type)
+        if (type == "node")
+            return(RET@get_where(newdata = newdata, 
+                                 mincriterion = mincriterion, ...))
 
         cdresp <- RET@cond_distr_response(newdata = newdata, 
                                           mincriterion = mincriterion, ...)
+        if (type == "prob")
+            return(cdresp)
 
         ### <FIXME> multivariate responses, we might want to return
         ###         a data.frame
